@@ -5,7 +5,7 @@ fake = Faker('es-ES')
 
 #                     NOMBRE Y APELLIDOS DE PERSONA FISICA
 #------------------------------------------------------------------------------------------
-#Datos sinteticos de nombre y apellidos cuando no hay una columna que especifique el sexo
+#Datos sinteticos de nombre y apellidos cuando no hay una columna que especifique el sexo con formato Apellido1 Apellido2;Nombre
 def full_name_MM_gender_random(row):
 
     name = ''
@@ -29,11 +29,26 @@ def full_name_gender_random(row):
     
     return(name)
 
+def fn_full_name_gender_random(row):
+    
+    name = ''
+    sex = np.random.randint(0, 2, 1)
+    if sex==1: # female
+        name = fake.last_name_female() + ' ' + fake.last_name_female() + '; ' + fake.first_name_female()
+    if sex!=1: # male
+        name = fake.last_name_male() + ' ' + fake.last_name_male() + '; ' + fake.first_name_male()
+        # randomly determine if two first name should be used:
+    if np.random.randint(0, 2, 1) == 1:
+         name = name + ' ' + fake.first_name_nonbinary()
+
+    return(name)
+
+
 #Nombre propio con género aleatorio
 def first_name_gender_random(row):
 
     name = ''
-    sex = np.random.randint(0, 1) 
+    sex = np.random.randint(0, 2) 
     if sex==1: # female
         name = fake.first_name_female()
     else: # male
@@ -197,7 +212,7 @@ door = {0:'B', 1:'D', 2:'F', 3:'A', 4:'G', 5:'C',
 def building_flat_door(row):
     num = "".join(["{}".format(np.random.randint(0, 2)) for i in range(2)])
     letter = door[int(num) % 12]
-    infoampl = str(num) +' '+ str(door)  
+    infoampl = str(num) +' '+ str(letter)  
     return(infoampl) 
 
 #Ciudad-localidad
@@ -227,21 +242,6 @@ def national_id(row):
     return(national_id)   
 
 
-#Letra del DNI
-
-#DNI
-
-letter_map = {0:'T', 1:'R', 2:'W', 3:'A', 4:'G', 5:'M', 
-              6:'Y', 7:'F', 8:'P', 9:'D', 10:'X', 11:'B', 
-              12:'N', 13:'J', 14:'Z', 15:'S', 16:'Q', 
-              17:'V', 18:'H', 19:'L', 20:'C', 21:'K', 22:'E'}
-
-def national_id_char(row):
-    letter = letter_map[int(id_num) % 23]
-    national_id_char= str(letter)
-       
-    return(national_id_char)   
-
 
 
 #          MATRICULA
